aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSeongJae Park <sj38.park@gmail.com>2024-03-09 11:56:43 -0800
committerSeongJae Park <sj38.park@gmail.com>2024-03-09 11:56:43 -0800
commit14f6f8493dac95c40d7b5809544a76a96a43a252 (patch)
tree1ba21a45eabcbdbb37a60e55d816e2243bc41782
parentbfde465f77ad592dc36cb72e07edb7dd17bc1785 (diff)
downloaddamo-14f6f8493dac95c40d7b5809544a76a96a43a252.tar.gz
_damon: Support 'young' type DAMOS filter
Signed-off-by: SeongJae Park <sj38.park@gmail.com>
-rw-r--r--_damon.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/_damon.py b/_damon.py
index 35130dec..52b0605f 100644
--- a/_damon.py
+++ b/_damon.py
@@ -602,7 +602,7 @@ class DamosWatermarks:
])
class DamosFilter:
- filter_type = None # anon, memcg, addr, or target
+ filter_type = None # anon, memcg, young, addr, or target
matching = None
memcg_path = None
address_range = None # DamonRegion
@@ -621,7 +621,7 @@ class DamosFilter:
def to_str(self, raw):
txt = '%s %s' % (self.filter_type,
'matching' if self.matching else 'nomatching')
- if self.filter_type == 'anon':
+ if self.filter_type in ['anon', 'young']:
return txt
if self.filter_type == 'memcg':
return '%s %s' % (txt, self.memcg_path)